import {Fragment, useEffect, useState} from '@wordpress/element';
import {useSelect} from "@wordpress/data";
import {InspectorControls} from "@wordpress/block-editor";
import {Panel} from "@wordpress/components";

const addLegalNoticeToCoreGallery = (BlockEdit) => {
	return (props) => {
		const [data, setData] = useState(null);
		let has_notice = false;

		const fetchedData = useSelect((select) => {
			if ('core/gallery' === props.name) {
				let imagesData = [];

				props.attributes.ids.forEach((id) => {
					imagesData.push(select('core').getEntityRecord('postType', 'attachment', id));
				});

				return imagesData;
			}
		}, [props]);

		useEffect(() => {
			setData(fetchedData);
		}, [fetchedData]);

		if (data) {
			const blockElement = document.querySelector(`[data-block="${props.clientId}"]`);
			if (blockElement) {
				const galleryItems = blockElement.querySelectorAll('.blocks-gallery-item');

				galleryItems.forEach((item, index) => {
					// Apply the chp-notice-img class if image has a legal notice
					if (data[index]?.meta?.chp_legal_notice) {
						has_notice = true;
						item.classList.add('chp-notice-img');
					}
				});
			}
		}

		if (has_notice) {
			return (
				<Fragment>
					<BlockEdit {...props} />
					<InspectorControls>
						<div className="chp-warning">
							<Panel>
								<p>One or more photos have a legal notice. Please contact the picture desk before
									using.</p>
							</Panel>
						</div>
					</InspectorControls>
				</Fragment>
			)
		} else {
			return <BlockEdit {...props} />
		}
	};
}

export {addLegalNoticeToCoreGallery}
