document.addEventListener('DOMContentLoaded', () => {

	// Util to create and return the legal warning text
	const legalNoticeText = () => {
		const alertDiv = document.createElement('div');
		alertDiv.className = 'chp-warning';
		alertDiv.innerHTML = '<p>This photo has a legal notice.</br>Please contact the picture desk before using.</p>';
		return alertDiv;
	}

	/**
	 * Show the legal warning on the Media Library (grid mode)
	 */
	const showLegalNotice = () => {

		// Check if wp.media is defined
		if (typeof wp === 'undefined' || typeof wp.media === 'undefined') return false;

		// Select the elements where we want to show the warning
		const modalContentDetails = document.querySelector('.attachment-details .attachment-info .details');
		const modalContentImageThumb = document.querySelector('.attachment-details .thumbnail');

		if (modalContentImageThumb) {
			// Check if the notice is already displayed
			if (!modalContentImageThumb.querySelector('div.chp-notice-img')) {
				// Check if the container has children
				const firstElement = modalContentImageThumb.children[0];
				// Create the wrapper for the first element
				let wrapper = document.createElement("div");
				wrapper.appendChild(firstElement);
				wrapper.classList.add('chp-notice-img');
				// Add the wrapper
				modalContentImageThumb.insertBefore(wrapper, modalContentImageThumb.firstChild);
			}
		}

		if (modalContentDetails) {
			// Check if the notice is already displayed
			if (!modalContentDetails.querySelector('div.chp-warning')) {
				// Append the alert to the modal content
				modalContentDetails.insertBefore(legalNoticeText(), modalContentDetails.firstChild);
			}
		}
	}

	if (typeof wp.media.view.Attachment.Library !== 'undefined') {

		const originalAttachmentLibrary = wp.media.view.Attachment.Library;

		// Append the chpNoticeClass custom class
		wp.media.view.Attachment.Library = originalAttachmentLibrary.extend({
			className: function () {
				const chpNoticeClass = this.model.get('chpNoticeClass') ? this.model.get('chpNoticeClass') : '';
				return `attachment ${chpNoticeClass}`;
			}
		});
	}

	// Trigger the function when clicking on an element with class .chp-notice
	document.addEventListener('click', (event) => {
		// Check if the clicked element has the class .chp-notice
		if (event.target.classList.contains('chp-notice')) {
			// Timeout is used to ensure the modal is fully loaded
			setTimeout(showLegalNotice, 100);
		}
	});

	/**
	 * Show the legal warning on the Media Frame
	 */
	if (typeof wp.media.view.MediaFrame.EditAttachments !== 'undefined') {

		const originalMediaFrameEditAttachments = wp.media.view.MediaFrame.EditAttachments;

		// Show the legal notices on the MediaFrame
		wp.media.view.MediaFrame.EditAttachments = originalMediaFrameEditAttachments.extend({
			className: function () {
				const chpNoticeClass = this.model.get('chpNoticeClass') ? this.model.get('chpNoticeClass') : '';
				if (chpNoticeClass) {
					setTimeout(showLegalNotice, 100);
				}
				return `edit-attachment-frame ${chpNoticeClass}`;
			}
		});
	}

	/**
	 * Show the legal warning on the WP Edit Media page
	 */
	const editMedia = (el) => {
		el.classList.add('chp-notice-img');
		el.parentNode.insertBefore(legalNoticeText(), el.nextSibling);
	}

	const el = document.querySelector('.wp_attachment_image p');
	if (el && metaData?.hasLegalNotice) {
		editMedia(el);
	}
});
